@@ -7,10 +7,13 @@
 		hourText: 'Valandos',
 		minuteText: 'Minutės',
 		secondText: 'Sekundės',
+		millisecText: 'Milisekundės',
 		timezoneText: 'Laiko zona',
 		currentText: 'Dabar',
 		closeText: 'Uždaryti',
 		timeFormat: 'hh:mm',
+		amNames: ['priešpiet', 'AM', 'A'],
+		pmNames: ['popiet', 'PM', 'P'],
 		ampm: false
 	};
 	$.timepicker.setDefaults($.timepicker.regional['lt']);
