@@ -7,10 +7,13 @@
 		hourText: 'Saat',
 		minuteText: 'Dakika',
 		secondText: 'Saniye',
+		millisecText: 'Milisaniyelik',
 		timezoneText: 'Zaman Dilimi',
 		currentText: 'Şu an',
 		closeText: 'Tamam',
 		timeFormat: 'hh:mm',
+		amNames: ['AM', 'A'],
+		pmNames: ['PM', 'P'],
 		ampm: false
 	};
 	$.timepicker.setDefaults($.timepicker.regional['tr']);
